module.exports={A:{A:{"2":"nB","8":"H D G E A","164":"B"},B:{"1":"q","1025":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","8":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b eB dB","322":"c d"},D:{"1":"0 1 2 3 4 5 6 8 h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","8":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g"},E:{"1":"7 9 B C K fB","8":"F O H D WB RB YB ZB","545":"G E A aB bB PB"},F:{"1":"0 1 2 3 4 5 6 U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","8":"7 9 E B C L N I J P Q R S T gB hB iB jB GB lB"},G:{"1":"wB xB yB zB 0B 1B 2B","8":"RB mB CB oB pB qB","545":"G rB SB tB uB vB"},H:{"2":"3B"},I:{"1":"QB","8":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"8":"D A"},K:{"1":"M","8":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"8":"A","164":"B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:4,C:"Web Cryptography"};
