module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB"},D:{"1":"0 1 2 3 4 5 6 8 t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M","194":"r s"},E:{"1":"fB","2":"7 F O H D G E A B C WB RB YB ZB aB bB PB","322":"9 K"},F:{"1":"0 1 2 3 4 5 6 g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d gB hB iB jB GB lB","194":"e AB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB","578":"yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C M GB"},L:{"1":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"1":"BC CC DC EC FC PB","2":"F"},Q:{"2":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:5,C:"MediaRecorder API"};
