module.exports={A:{A:{"1":"E A B","2":"H D G nB"},B:{"1":"C K f L N I J","16":"q"},C:{"1":"0 1 2 3 4 5 6 8 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f eB dB"},D:{"1":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d","2":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q","16":"sB UB VB"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","2":"F O WB RB"},F:{"1":"7 9 B C L N I J P Q R S T U hB iB jB GB lB","2":"0 1 2 3 4 5 6 E V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB mB CB"},H:{"16":"3B"},I:{"1":"F QB 7B CB 8B 9B","16":"OB 4B 5B 6B"},J:{"16":"D A"},K:{"1":"9 C M","16":"7 A B GB"},L:{"1":"q"},M:{"1":"8"},N:{"16":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"Media attribute"};
