module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"f L N I J","2":"C K","257":"q"},C:{"1":"0 1 2 3 4 5 6 8 t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a eB dB","194":"b c d e AB g h i j k l m n o p M r s"},D:{"1":"d e AB g h i j k l m n o p M r s t u v w x y","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c","257":"0 1 2 3 4 5 6 8 z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 D G E A B C K aB bB PB fB","2":"F O H WB RB YB ZB"},F:{"1":"0 1 2 3 4 5 X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S T U V W gB hB iB jB GB lB","257":"6"},G:{"1":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB oB pB"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"1":"BC CC DC EC FC PB","2":"F"},Q:{"1":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:7,C:"Speech Synthesis API"};
