module.exports={A:{A:{"2":"nB","8":"H D G E A","129":"B"},B:{"1":"q","129":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","129":"F O H D G E A B C K f L N I J P Q R S T"},D:{"1":"0 1 2 3 4 5 6 8 d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D","129":"G E A B C K f L N I J P Q R S T U V W X Y Z a b c"},E:{"1":"7 9 G E A B C K bB PB fB","2":"F O WB RB","129":"H D YB ZB aB"},F:{"1":"0 1 2 3 4 5 6 P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 E B gB hB iB jB GB lB","129":"9 C L N I J"},G:{"1":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB oB pB qB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"1":"A","2":"D"},K:{"1":"9 C M","2":"7 A B GB"},L:{"1":"q"},M:{"1":"8"},N:{"8":"A","129":"B"},O:{"129":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"129":"IC"}},B:6,C:"WebGL - 3D Canvas graphics"};
