module.exports={A:{A:{"1":"B","2":"H D G E nB","289":"A"},B:{"1":"C K f L N I J q"},C:{"1":"1 2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB","194":"Z a b c d e AB g h i j k l m n o p M r s t u v","1025":"0 w x y z"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S gB hB iB jB GB lB"},G:{"1":"0B 1B 2B","2":"G RB mB CB oB pB qB rB SB","516":"tB uB vB wB xB yB zB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"B","289":"A"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"194":"IC"}},B:2,C:"CSS touch-action property"};
