module.exports={A:{A:{"2":"H D G E nB","129":"A B"},B:{"1":"q","129":"C K","1025":"f L N I J"},C:{"2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB","513":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"0 1 2 3 4 5 6 8 H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O"},E:{"1":"7 9 O H D G E A B C K YB ZB aB bB PB fB","2":"F WB RB"},F:{"1":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"388":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB 4B 5B 6B","388":"F QB 7B CB 8B 9B"},J:{"2":"D","388":"A"},K:{"1":"7 9 A B C GB","388":"M"},L:{"388":"q"},M:{"641":"8"},N:{"388":"A B"},O:{"388":"AC"},P:{"388":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"388":"HC"},S:{"513":"IC"}},B:1,C:"Number input type"};
