module.exports={A:{A:{"2":"H D G nB","260":"E A B"},B:{"1":"q","260":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S eB dB","132":"T U V W X Y"},D:{"1":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u"},E:{"1":"7 9 B C K PB fB","2":"F O H D G E A WB RB YB ZB aB bB"},F:{"1":"0 1 2 3 4 5 6 9 i j k l m n o p M r s t u v w x y z","2":"7 E B L N I J P Q R S T U V W X Y Z a b c d e AB g h gB hB iB jB GB lB","16":"C"},G:{"1":"vB wB xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB SB tB uB"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"1":"9","2":"7 A B GB","16":"C M"},L:{"1":"q"},M:{"1":"8"},N:{"260":"A B"},O:{"2":"AC"},P:{"1":"BC CC DC EC FC PB","2":"F"},Q:{"2":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:5,C:"KeyboardEvent.key"};
