module.exports={A:{A:{"1":"B","2":"H D G E A nB"},B:{"2":"C K f L N I J q"},C:{"1":"K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u","2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u","2":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 G E A B C bB PB","2":"F O H D WB RB YB ZB aB","129":"9 K fB"},F:{"1":"9 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j m o","2":"0 1 2 3 4 5 6 7 E B C k l n p M r s t u v w x y z gB hB iB jB GB lB"},G:{"1":"G rB SB tB uB vB wB xB yB","2":"RB mB CB oB pB qB","257":"zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"OB F 7B CB 8B 9B","2":"QB 4B 5B 6B"},J:{"2":"D A"},K:{"1":"9","2":"7 A B C M GB"},L:{"2":"q"},M:{"2":"8"},N:{"1":"B","2":"A"},O:{"2":"AC"},P:{"1":"F","2":"BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"16":"HC"},S:{"1":"IC"}},B:7,C:"SPDY protocol"};
