module.exports={A:{A:{"2":"E A B nB","4":"H D G"},B:{"2":"C K f L N I J","8":"q"},C:{"8":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"8":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"8":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"8":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"8":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"8":"3B"},I:{"8":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"8":"D A"},K:{"8":"7 9 A B C M GB"},L:{"8":"q"},M:{"8":"8"},N:{"2":"A B"},O:{"8":"AC"},P:{"8":"F BC CC DC EC FC PB"},Q:{"8":"GC"},R:{"8":"HC"},S:{"8":"IC"}},B:7,C:"XHTML+SMIL animation"};
