module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"L N I J q","2":"C K f"},C:{"1":"0 1 2 3 4 5 6 8 X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","33":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W eB dB"},D:{"1":"8 HB IB JB KB LB MB cB QB XB TB q sB UB VB","33":"0 1 2 3 4 5 6 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB"},E:{"1":"7 9 B C K fB","33":"F O H D G E A WB RB YB ZB aB bB PB"},F:{"1":"0 1 2 3 4 5 6 9 C z lB","2":"7 E B gB hB iB jB GB","33":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"33":"D A"},K:{"2":"7 9 A B C GB","33":"M"},L:{"1":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"2":"F BC CC DC EC FC PB"},Q:{"33":"GC"},R:{"2":"HC"},S:{"2":"IC"}},B:3,C:"CSS grab & grabbing cursors"};
