module.exports={A:{A:{"2":"E A B nB","8":"H D G"},B:{"2":"C K f L N I J q"},C:{"2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h","2":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","130":"i j k l m n o p M r s t u"},E:{"1":"7 9 F O H D G E A B C K RB YB ZB aB bB PB fB","2":"WB"},F:{"1":"7 9 E B C L N I J P Q R S T U gB hB iB jB GB lB","2":"0 1 2 3 4 5 6 h i j k l m n o p M r s t u v w x y z","130":"V W X Y Z a b c d e AB g"},G:{"1":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"258":"3B"},I:{"1":"OB F 7B CB 8B 9B","2":"QB 4B 5B 6B"},J:{"1":"D A"},K:{"1":"7 9 A B C M GB"},L:{"130":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"1":"F","130":"BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"130":"HC"},S:{"2":"IC"}},B:2,C:"SVG fonts"};
