module.exports={A:{A:{"2":"H D G E nB","6308":"A","6436":"B"},B:{"1":"q","6436":"C K f L N I J"},C:{"1":"8 HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i eB dB","2052":"0 1 2 3 4 5 6 j k l m n o p M r s t u v w x y z EB NB DB BB FB"},D:{"1":"HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"0 1 2 3 4 5 6 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB","8258":"8 BB FB"},E:{"1":"7 9 B C K fB","2":"F O H D G WB RB YB ZB aB","3108":"E A bB PB"},F:{"1":"6","2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x gB hB iB jB GB lB","8258":"0 1 2 3 4 5 y z"},G:{"1":"wB xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB","3108":"SB tB uB vB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C M GB"},L:{"1":"q"},M:{"2052":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"1":"PB","2":"F BC CC DC EC FC"},Q:{"2":"GC"},R:{"2":"HC"},S:{"2052":"IC"}},B:4,C:"CSS Scroll Snap"};
