module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"f L N I J q","2":"C K"},C:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB"},D:{"1":"0 1 2 3 4 5 6 8 Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P"},E:{"1":"9 K fB","2":"7 F O H D G E A B C WB RB YB ZB aB bB PB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z GB lB","2":"E L N gB hB iB jB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB","129":"zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB 8B 9B","2":"OB F 4B 5B 6B 7B CB"},J:{"1":"D A"},K:{"1":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"2":"IC"}},B:1,C:"Color input type"};
