module.exports={A:{A:{"1":"E A B","16":"nB","132":"H D G"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","132":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z"},E:{"1":"7 9 D G E A B C K ZB aB bB PB fB","16":"WB","132":"F O H RB YB"},F:{"1":"0 1 2 3 4 5 6 I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","16":"E gB","132":"7 9 B C L N hB iB jB GB lB"},G:{"1":"G mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB"},H:{"2":"3B"},I:{"1":"QB 8B 9B","16":"4B 5B","132":"OB F 6B 7B CB"},J:{"132":"D A"},K:{"1":"M","132":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:2,C:"letter-spacing CSS property"};
