module.exports={A:{A:{"2":"nB","8":"H D G","129":"E A B"},B:{"1":"I J q","129":"C K f L N"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","8":"kB OB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","8":"F O H"},E:{"1":"7 9 E A B C K bB PB fB","8":"F O WB RB","129":"H D G YB ZB aB"},F:{"1":"0 1 2 3 4 5 6 9 C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z lB","2":"7 B jB GB","8":"E gB hB iB"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","8":"RB mB CB","129":"G oB pB qB rB"},H:{"1":"3B"},I:{"1":"QB 8B 9B","2":"4B 5B 6B","129":"OB F 7B CB"},J:{"1":"A","129":"D"},K:{"1":"9 C M","8":"7 A B GB"},L:{"1":"q"},M:{"1":"8"},N:{"129":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"Inline SVG in HTML5"};
