module.exports={A:{A:{"1":"H D G E A B nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f eB dB"},D:{"1":"0 1 2 3 4 5 6 8 o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","4":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n"},E:{"1":"7 9 E A B C K bB PB fB","4":"F O H D G WB RB YB ZB aB"},F:{"1":"0 1 2 3 4 5 6 b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","4":"L N I J P Q R S T U V W X Y Z a"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","4":"G RB mB CB oB pB qB rB"},H:{"2":"3B"},I:{"1":"QB","4":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"4":"D A"},K:{"2":"7 9 A B C GB","4":"M"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"4":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"4":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:5,C:"CSS3 word-break"};
