module.exports={A:{A:{"2":"H D G nB","260":"E A B"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f eB dB"},D:{"1":"0 1 2 3 4 5 6 8 u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB","132":"g h i j k l m n o p M r s t"},E:{"1":"7 9 C K fB","2":"F O H D E A B WB RB YB ZB bB PB","132":"G aB"},F:{"1":"0 1 2 3 4 5 6 9 h i j k l m n o p M r s t u v w x y z","2":"L N I J P Q R S","4":"7 B C hB iB jB GB lB","16":"E gB","132":"T U V W X Y Z a b c d e AB g"},G:{"1":"xB yB zB 0B 1B 2B","2":"RB mB CB oB pB qB SB tB uB vB wB","132":"G rB"},H:{"1":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D","132":"A"},K:{"1":"9 M","4":"7 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","132":"F"},Q:{"132":"GC"},R:{"132":"HC"},S:{"1":"IC"}},B:4,C:"SVG fragment identifiers"};
