module.exports={A:{A:{"2":"H D G nB","132":"E A B"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB","260":"F O H D G E A B C K f L eB dB"},D:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","548":"F O H D G E A B C K f L N I J P Q R S T U V W X Y"},E:{"2":"WB RB","548":"7 9 F O H D G E A B C K YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 9 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E","548":"7 B C gB hB iB jB GB lB"},G:{"16":"RB","548":"G mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"132":"3B"},I:{"1":"QB 8B 9B","16":"4B 5B","548":"OB F 6B 7B CB"},J:{"548":"D A"},K:{"1":"9 M","548":"7 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"132":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:2,C:"Media Queries: resolution feature"};
