module.exports={A:{A:{"2":"H D G nB","4":"E A B"},B:{"1":"I J q","4":"C K f L N"},C:{"1":"0 1 2 3 4 5 6 8 o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB eB dB","194":"g h i j k l m n"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","4":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB"},E:{"1":"7 9 A B C K PB fB","4":"F O H D G E WB RB YB ZB aB bB"},F:{"1":"0 1 2 3 4 5 6 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","4":"L N I J P Q R S"},G:{"1":"uB vB wB xB yB zB 0B 1B 2B","4":"G RB mB CB oB pB qB rB SB tB"},H:{"2":"3B"},I:{"1":"QB","4":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D","4":"A"},K:{"2":"7 9 A B C GB","4":"M"},L:{"1":"q"},M:{"1":"8"},N:{"4":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","4":"F"},Q:{"1":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:4,C:"Font unicode-range subsetting"};
