module.exports={A:{A:{"1":"B","16":"nB","132":"H D G E A"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","132":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB"},D:{"1":"0 1 2 3 4 5 6 8 U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","132":"F O H D G E A B C K f L N I J P Q R S T"},E:{"1":"7 9 A B C K PB fB","132":"F O H D G E WB RB YB ZB aB bB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","16":"7 E B C gB hB iB jB GB lB","132":"9"},G:{"1":"uB vB wB xB yB zB 0B 1B 2B","132":"G RB mB CB oB pB qB rB SB tB"},H:{"132":"3B"},I:{"1":"QB 8B 9B","132":"OB F 4B 5B 6B 7B CB"},J:{"132":"D A"},K:{"1":"M","16":"7 A B C GB","132":"9"},L:{"1":"q"},M:{"1":"8"},N:{"1":"B","132":"A"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","132":"F"},Q:{"132":"GC"},R:{"1":"HC"},S:{"4":"IC"}},B:6,C:"localeCompare()"};
