module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"I J","2":"C K f L N","257":"q"},C:{"2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n eB dB","257":"0 1 2 4 5 6 8 o M r s t u v x y z EB NB DB BB FB HB IB JB KB LB MB","1281":"3 p w"},D:{"2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n","257":"0 1 2 3 4 5 6 8 u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","388":"o p M r s t"},E:{"2":"F O H D G E WB RB YB ZB aB","514":"7 9 A B C K bB PB fB"},F:{"2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g gB hB iB jB GB lB","16":"h i j k l","257":"0 1 2 3 4 5 6 m n o p M r s t u v w x y z"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"2":"HC"},S:{"257":"IC"}},B:5,C:"Push API"};
