module.exports={A:{A:{"2":"H D G E A nB","2052":"B"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","194":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n eB dB"},D:{"1":"0 1 2 3 4 5 6 8 t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J","322":"P Q R S T U V W X Y Z a b c d e AB g h i j k","516":"l m n o p M r s"},E:{"1":"7 9 B C K fB","2":"F O H D G E WB RB YB ZB aB bB","1028":"A PB"},F:{"1":"0 1 2 3 4 5 6 g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","322":"L N I J P Q R S T U V W X","516":"Y Z a b c d e AB"},G:{"1":"wB xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB SB tB","1028":"uB vB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"B","2":"A"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","516":"F"},Q:{"2":"GC"},R:{"516":"HC"},S:{"1":"IC"}},B:6,C:"let"};
