module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I","260":"q","3138":"J"},C:{"1":"0 1 2 3 4 5 6 8 y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB","132":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M eB dB","644":"r s t u v w x"},D:{"2":"F O H D G E A B C K f L N I J P Q R S T","260":"0 1 2 3 4 5 6 8 z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","292":"U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y"},E:{"2":"F O H WB RB YB ZB","292":"7 9 D G E A B C K aB bB PB fB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","260":"0 1 2 3 4 5 6 m n o p M r s t u v w x y z","292":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l"},G:{"2":"RB mB CB oB pB","292":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB","260":"QB","292":"8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","292":"M"},L:{"260":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"292":"AC"},P:{"292":"F BC CC DC EC FC PB"},Q:{"292":"GC"},R:{"260":"HC"},S:{"644":"IC"}},B:4,C:"CSS clip-path property (for HTML)"};
