module.exports={A:{A:{"2":"E A B nB","8":"H D G"},B:{"2":"C K f L N I J","8":"q"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","129":"kB OB eB dB"},D:{"1":"U","8":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 A B C K PB fB","260":"F O H D G E WB RB YB ZB aB bB"},F:{"2":"E","4":"7 9 B C gB hB iB jB GB lB","8":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","8":"RB mB CB"},H:{"8":"3B"},I:{"8":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"1":"A","8":"D"},K:{"8":"7 9 A B C M GB"},L:{"8":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"4":"AC"},P:{"8":"F BC CC DC EC FC PB"},Q:{"8":"GC"},R:{"8":"HC"},S:{"1":"IC"}},B:2,C:"MathML"};
