module.exports={A:{A:{"2":"nB","8":"H D G","260":"E A B"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB","132":"OB eB dB","260":"F O H D G E A B C K f L N I J P Q"},D:{"1":"0 1 2 3 4 5 6 8 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","132":"F O","260":"H D G E A B C K f L N I J P Q R S T U V"},E:{"1":"7 9 D G E A B C K ZB aB bB PB fB","132":"F WB RB","260":"O H YB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","132":"E B gB hB iB jB","260":"7 9 C GB lB"},G:{"1":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","132":"RB","260":"mB CB oB pB"},H:{"132":"3B"},I:{"1":"QB 8B 9B","132":"4B","260":"OB F 5B 6B 7B CB"},J:{"260":"D A"},K:{"1":"M","132":"A","260":"7 9 B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"260":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"HTML5 semantic elements"};
