module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"C K f L N I J","2":"q"},C:{"2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"2":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 H D G E A B C K ZB aB bB PB fB","2":"F O WB RB YB"},F:{"2":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"1":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"OB F QB 7B CB 8B 9B","2":"4B 5B 6B"},J:{"1":"A","2":"D"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"2":"IC"}},B:7,C:"HTTP Live Streaming (HLS)"};
