module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F eB dB","33":"O H D G E A B C K f L"},D:{"1":"0 1 2 3 4 5 6 8 n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","33":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m"},E:{"1":"7 9 E A B C K bB PB fB","2":"WB RB","33":"H D G YB ZB aB","292":"F O"},F:{"1":"0 1 2 3 4 5 6 9 a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 E B gB hB iB jB GB lB","33":"C L N I J P Q R S T U V W X Y Z"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","33":"G pB qB rB","164":"RB mB CB oB"},H:{"2":"3B"},I:{"1":"QB","33":"F 7B CB 8B 9B","164":"OB 4B 5B 6B"},J:{"33":"D A"},K:{"1":"9 M","2":"7 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"33":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:5,C:"CSS Animation"};
