module.exports={A:{A:{"2":"E A B nB","8":"H D G"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB","8":"OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M eB dB","194":"r s"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","8":"F O H D G E A B","257":"P Q R S T U V W X Y Z a b c d e AB","769":"C K f L N I J"},E:{"1":"9 C K fB","8":"F O WB RB YB","257":"H D G E A ZB aB bB","1025":"7 B PB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 C GB lB","8":"E B gB hB iB jB"},G:{"1":"G pB qB rB SB tB xB yB zB 0B 1B 2B","8":"RB mB CB oB","1025":"uB vB wB"},H:{"8":"3B"},I:{"1":"F QB 7B CB 8B 9B","8":"OB 4B 5B 6B"},J:{"1":"A","8":"D"},K:{"1":"M","8":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"769":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"Details & Summary elements"};
