module.exports={A:{A:{"644":"H D G E nB","772":"A B"},B:{"1":"J q","260":"C K f L N I"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB","8":"kB OB"},D:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 9 C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","8":"7 E B gB hB iB jB GB lB"},G:{"1":"wB xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB SB tB uB vB"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"1":"9","2":"M","8":"7 A B C GB"},L:{"1":"q"},M:{"2":"8"},N:{"1":"A B"},O:{"2":"AC"},P:{"2":"F BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"2":"HC"},S:{"2":"IC"}},B:1,C:"Drag and Drop"};
