module.exports={A:{A:{"1":"E A B","16":"nB","516":"G","1540":"H D"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB","132":"OB","260":"kB"},D:{"1":"0 1 2 3 4 5 6 8 E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","16":"O H D G","132":"F"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","16":"O WB","132":"F RB"},F:{"1":"0 1 2 3 4 5 6 9 C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z lB","16":"E gB","260":"7 B hB iB jB GB"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB mB CB"},H:{"1":"3B"},I:{"1":"OB F QB 7B CB 8B 9B","16":"4B 5B","132":"6B"},J:{"1":"D A"},K:{"1":"9 C M","260":"7 A B GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:2,C:"::first-letter CSS pseudo-element selector"};
