module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K","132":"f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a eB dB","132":"b c d e AB g h i j k l m n o p M r"},D:{"1":"8 HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB","132":"0 1 2 3 4 5 6 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB"},E:{"1":"7 9 A B C K bB PB fB","2":"F O H D WB RB YB ZB","132":"G E aB"},F:{"1":"0 1 2 3 4 5 6 z","2":"7 9 E B C L N I J P Q R S gB hB iB jB GB lB","132":"T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB oB pB qB","16":"G","132":"rB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"1":"A","2":"D"},K:{"2":"7 9 A B C GB","132":"M"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"132":"AC"},P:{"1":"PB","132":"F BC CC DC EC FC"},Q:{"132":"GC"},R:{"132":"HC"},S:{"1":"IC"}},B:1,C:"Path2D"};
