module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y eB dB"},D:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"O H YB","2":"7 9 F D G E A B C K WB RB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z jB GB lB","2":"E gB hB iB"},G:{"1":"oB pB","2":"G RB mB CB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"1":"D A"},K:{"1":"7 9 B C GB","2":"M","16":"A"},L:{"2":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"1":"F","2":"BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:1,C:"Shared Web Workers"};
