module.exports={A:{A:{"1":"A B","2":"H D nB","260":"E","1026":"G"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","4":"kB OB eB dB","132":"F O H D G E A B C K f L N I J P Q"},D:{"1":"0 1 2 3 4 5 6 8 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","4":"F O H D G E A B C K f L N I J","132":"P Q R S"},E:{"1":"7 9 H D G E A B C K ZB aB bB PB fB","4":"F O WB RB YB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","4":"7 E B C gB hB iB jB GB lB","132":"9"},G:{"1":"G pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","4":"RB mB CB oB"},H:{"132":"3B"},I:{"1":"QB 8B 9B","4":"OB 4B 5B 6B","132":"7B CB","900":"F"},J:{"1":"A","4":"D"},K:{"1":"M","4":"7 A B C GB","132":"9"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:6,C:"ECMAScript 5"};
