module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f","194":"q","257":"L N I J"},C:{"2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB eB dB","16":"LB MB"},D:{"2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i","16":"0 1 j k l m n o p M r s t u v w x y z","194":"2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"F O H D G WB RB YB ZB aB","16":"7 9 E A B C K bB PB fB"},F:{"2":"7 9 E B C L N I J P Q R S T U V W X Y Z gB hB iB jB GB lB","16":"0 1 2 3 4 5 6 a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"2":"G RB mB CB oB pB qB rB","16":"SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"16":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB 8B 9B","16":"QB"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","16":"M"},L:{"16":"q"},M:{"16":"8"},N:{"2":"A","16":"B"},O:{"16":"AC"},P:{"16":"F BC CC DC EC FC PB"},Q:{"16":"GC"},R:{"16":"HC"},S:{"2":"IC"}},B:6,C:"Token Binding"};
