module.exports={A:{A:{"1":"H D G E A nB","132":"B"},B:{"132":"C K f L N I J","260":"q"},C:{"1":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z eB dB","516":"0 1 2 3 4 5 6 8 a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"I J P Q R S T U V W","2":"F O H D G E A B C K f L N","132":"X Y Z a b c d e AB g h i j k","260":"0 1 2 3 4 5 6 8 l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"H YB ZB","2":"F O WB RB","2052":"7 9 D G E A B C K aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"2":"RB mB CB","1025":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"1025":"3B"},I:{"1":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"1":"D A"},K:{"1":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"2052":"A B"},O:{"1025":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"260":"GC"},R:{"1":"HC"},S:{"516":"IC"}},B:1,C:"autocomplete attribute: on & off values"};
