module.exports={A:{A:{"2":"H D G nB","36":"E A B"},B:{"1":"L N I J q","36":"C K f"},C:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB","36":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d dB"},D:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","36":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d"},E:{"1":"7 9 G E A B C K aB bB PB fB","2":"F WB RB","36":"O H D YB ZB"},F:{"1":"0 1 2 3 4 5 6 R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 E B gB hB iB jB","36":"9 C L N I J P Q GB lB"},G:{"1":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB","36":"mB CB oB pB qB"},H:{"2":"3B"},I:{"1":"QB","2":"4B","36":"OB F 5B 6B 7B CB 8B 9B"},J:{"36":"D A"},K:{"1":"M","2":"A B","36":"7 9 C GB"},L:{"1":"q"},M:{"1":"8"},N:{"36":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","36":"F"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"matches() DOM method"};
