module.exports={A:{A:{"2":"H D G E nB","33":"A B"},B:{"1":"q","33":"C K f L N I J"},C:{"1":"HB IB JB KB LB MB","33":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","33":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x"},E:{"33":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","33":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k"},G:{"33":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","33":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"33":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"33":"8"},N:{"33":"A B"},O:{"2":"AC"},P:{"33":"F BC CC DC EC FC PB"},Q:{"33":"GC"},R:{"2":"HC"},S:{"33":"IC"}},B:5,C:"CSS user-select: none"};
