module.exports={A:{A:{"2":"H D G E A nB","132":"B"},B:{"1":"C K f L N I J","4":"q"},C:{"2":"kB OB eB","4":"0 1 2 3 4 5 6 8 H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","8":"F O dB"},D:{"2":"F O H","4":"0 1 2 3 4 5 6 8 D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","4":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"2":"RB mB","4":"G CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"4B 5B 6B","4":"OB F QB 7B CB 8B 9B"},J:{"2":"D","4":"A"},K:{"1":"9 C","2":"7 A B GB","4":"M"},L:{"4":"q"},M:{"4":"8"},N:{"1":"B","2":"A"},O:{"4":"AC"},P:{"4":"F BC CC DC EC FC PB"},Q:{"4":"GC"},R:{"4":"HC"},S:{"4":"IC"}},B:4,C:"DeviceOrientation & DeviceMotion events"};
