module.exports={A:{A:{"2":"H D G nB","260":"E A B"},B:{"132":"q","260":"C K f L N I J"},C:{"2":"kB OB F O eB dB","260":"0 1 2 3 4 5 6 8 H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"16":"F O H D G E A B C K f","132":"0 1 2 3 4 5 6 8 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"16":"WB RB","132":"7 9 F O H D G E A B C K YB ZB aB bB PB fB"},F:{"1":"9 C lB","2":"E gB hB iB jB","16":"7 B GB","132":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"16":"RB mB","132":"G CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"16":"4B 5B","132":"OB F QB 6B 7B CB 8B 9B"},J:{"132":"D A"},K:{"1":"9 C","2":"A","16":"7 B GB","132":"M"},L:{"132":"q"},M:{"260":"8"},N:{"260":"A B"},O:{"132":"AC"},P:{"132":"F BC CC DC EC FC PB"},Q:{"132":"GC"},R:{"132":"HC"},S:{"260":"IC"}},B:5,C:"Mutation events"};
