module.exports={A:{A:{"2":"H D G E nB","129":"A B"},B:{"1":"q","129":"C K f L N I J"},C:{"2":"kB OB eB dB","129":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"0 1 2 3 4 5 6 8 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","16":"F O H D G E A B C K f R S T U V","129":"L N I J P Q"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","16":"F O WB RB"},F:{"1":"0 1 2 3 4 5 6 9 C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z lB","2":"E gB hB iB jB","16":"7 B GB"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB mB CB"},H:{"129":"3B"},I:{"1":"QB 8B 9B","16":"4B 5B","129":"OB F 6B 7B CB"},J:{"1":"D","129":"A"},K:{"1":"C","2":"A","16":"7 B GB","129":"9 M"},L:{"1":"q"},M:{"129":"8"},N:{"129":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"129":"IC"}},B:1,C:"Search input type"};
