module.exports={A:{A:{"132":"H D G E A B nB"},B:{"1":"q","132":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 u v w x y z EB NB DB BB FB HB IB JB KB LB MB","33":"I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t","132":"kB OB F O H D G E eB dB","292":"A B C K f L N"},D:{"1":"0 1 2 3 4 5 6 8 s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","132":"F O H D G E A B C K f L N","548":"I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r"},E:{"132":"F O H D G WB RB YB ZB aB","548":"7 9 E A B C K bB PB fB"},F:{"132":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"132":"G RB mB CB oB pB qB rB","548":"SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"16":"3B"},I:{"1":"QB","16":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"16":"D A"},K:{"16":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"132":"A B"},O:{"16":"AC"},P:{"1":"BC CC DC EC FC PB","16":"F"},Q:{"16":"GC"},R:{"16":"HC"},S:{"33":"IC"}},B:4,C:"CSS unicode-bidi property"};
