module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","33":"L N I J P Q R S T U V W X Y Z a b c d","164":"F O H D G E A B C K f"},D:{"1":"0 1 2 3 4 5 6 8 s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L","33":"R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r","292":"N I J P Q"},E:{"1":"7 9 A B C K bB PB fB","2":"D G E WB RB ZB aB","4":"F O H YB"},F:{"1":"0 1 2 3 4 5 6 AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","33":"L N I J P Q R S T U V W X Y Z a b c d e"},G:{"1":"tB uB vB wB xB yB zB 0B 1B 2B","2":"G qB rB SB","4":"RB mB CB oB pB"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB","33":"8B 9B"},J:{"2":"D","33":"A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","33":"F"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:4,C:"CSS font-feature-settings"};
